import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import { useState, useEffect, useRef, useCallback } from 'react';
import Button from '@s-ui/react-atom-button';
import cx from 'classnames';
import PropTypes from 'prop-types';
import { SIZES, PLACEMENTS } from './config';
var BASE_CLASS = 'sui-MoleculeSelectPopover';

function usePrevious(value) {
  var ref = useRef();
  useEffect(function () {
    ref.current = value;
  }, [value]);
  return ref.current;
}

function MoleculeSelectPopover(_ref) {
  var acceptButtonText = _ref.acceptButtonText,
      cancelButtonText = _ref.cancelButtonText,
      children = _ref.children,
      hideActions = _ref.hideActions,
      IconArrowDown = _ref.iconArrowDown,
      _ref$isSelected = _ref.isSelected,
      isSelected = _ref$isSelected === void 0 ? false : _ref$isSelected,
      _ref$onAccept = _ref.onAccept,
      onAccept = _ref$onAccept === void 0 ? function () {} : _ref$onAccept,
      _ref$onCancel = _ref.onCancel,
      onCancel = _ref$onCancel === void 0 ? function () {} : _ref$onCancel,
      _ref$onClose = _ref.onClose,
      onClose = _ref$onClose === void 0 ? function () {} : _ref$onClose,
      _ref$onOpen = _ref.onOpen,
      onOpen = _ref$onOpen === void 0 ? function () {} : _ref$onOpen,
      _ref$placement = _ref.placement,
      placement = _ref$placement === void 0 ? PLACEMENTS.RIGHT : _ref$placement,
      selectText = _ref.selectText,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'm' : _ref$size,
      title = _ref.title;

  var _useState = useState(false),
      isOpen = _useState[0],
      setIsOpen = _useState[1];

  var previousIsOpen = usePrevious(isOpen);
  useEffect(function () {
    /**
     * Only run open events:
     *  - After first render
     *  - When isOpen actually changes
     **/
    if (typeof previousIsOpen === 'undefined' || isOpen === previousIsOpen) {
      return;
    }

    var openEvent = isOpen ? onOpen : onClose;
    openEvent();
  }, [isOpen, onClose, onOpen, previousIsOpen]);
  var selectRef = useRef();
  var popoverRef = useRef();
  var selectClassName = cx(BASE_CLASS + "-select", BASE_CLASS + "-select--" + size, {
    'is-open': isOpen,
    'is-selected': isSelected
  });
  var popoverClassName = cx(BASE_CLASS + "-popover", BASE_CLASS + "-popover--" + placement);

  var handleOnAccept = function handleOnAccept() {
    setIsOpen(false);
    onAccept();
  };

  var handleOnCancel = useCallback(function () {
    setIsOpen(false);
    onCancel();
  }, [onCancel]);
  useEffect(function () {
    var handleClickOutside = function handleClickOutside(e) {
      if (isOpen && !popoverRef.current.contains(e.target) && !selectRef.current.contains(e.target)) {
        handleOnCancel();
      }
    };

    window.addEventListener('mousedown', handleClickOutside);
    return function () {
      window.removeEventListener('mousedown', handleClickOutside);
    };
  }, [handleOnCancel, isOpen]);

  var handleOpenToggle = function handleOpenToggle() {
    if (isOpen) {
      setIsOpen(false);
      handleOnCancel();
      return;
    }

    setIsOpen(true);
  };

  return /*#__PURE__*/_jsxs("div", {
    className: BASE_CLASS,
    title: title,
    children: [/*#__PURE__*/_jsxs("div", {
      ref: selectRef,
      className: selectClassName,
      onClick: handleOpenToggle,
      children: [/*#__PURE__*/_jsx("span", {
        className: BASE_CLASS + "-selectText",
        children: selectText
      }), /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-selectIcon",
        children: /*#__PURE__*/_jsx(IconArrowDown, {})
      })]
    }), isOpen && /*#__PURE__*/_jsxs("div", {
      className: popoverClassName,
      ref: popoverRef,
      children: [/*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-popoverContent",
        children: children
      }), !hideActions && /*#__PURE__*/_jsxs("div", {
        className: BASE_CLASS + "-popoverActionBar",
        children: [/*#__PURE__*/_jsx(Button, {
          onClick: handleOnCancel,
          design: "flat",
          children: cancelButtonText
        }), /*#__PURE__*/_jsx(Button, {
          onClick: handleOnAccept,
          children: acceptButtonText
        })]
      })]
    })]
  });
}

MoleculeSelectPopover.displayName = 'MoleculeSelectPopover';
export default MoleculeSelectPopover;
export { SIZES as selectPopoverSizes, PLACEMENTS as selectPopoverPlacements };